-HEIDI: This season
on Project Runway... -[whoops]
TIM:
Go!
Did you ever think you'd find
yourselves in a boxing ring?
The coldest place in Manhattan.
HEIDI: You're sleeping on top
of the Empire State Building!
I have breakfast sandwiches
for everyone!
Your first unconventional
materials challenge.
-They're off! -[laughs]
-Shake your little booty!
[humming]
Ha!
[crying]
You know I love you so much.
We definitely understand
how hard this must be.
It's a very hard place to be in.
For all of us.
♪ ♪
♪ Hallelujah ♪
That was like,
"Ugh, there goes my heart."
Wow. You did amazing.
HEIDI:
And our guest judge for today,
Demi Lovato,
Dove Cameron,
Olivia Munn, Kate Upton,
China Anne McClain,
Kelsea Ballerini,
Katie Holmes, Maddie Ziegler,
Yolanda Hadid,
and Asia Kate Dillon.
The way that it was done,
I do not agree with.
Michael, why are you running
off the stage?
TIM: This has never happened
in the history of the show.
I came to play fair, and...
there's no fairness
in this game.
-What happened?
-I have no idea.
Well, somebody needs to explain.
This is cheating.
It all has to stop.
This entire thing disgusts me.
It was unprofessional,
unseemly, atrocious.
♪ ♪
♪ ♪
[horns honking]
I'm ready.
I brought the "A" game,
taken my vitamin C, I'm not
kidding around,
I'm gonna make these dresses,
and I'm coming to m*rder
you guys... in a nice way.
AARON:
The beauty of fashion is
there's no rules anymore.
He's a dude wearing a dress,
like, this is crazy,
but, for me, it's just normal.
I feel like a badass.
I feel like
I just entered
an exclusive club.
-[horn honks]
-I feel freakin' awesome.
♪ ♪
MARGARITA: Winning
Project Runway would mean
the world to me.
It would mean the world.
What is wrong with me?
It's the first day.
[ice clattering]
[chuckles]
My God, nobody's here.
[whispers]: This is fabulous.
-I'm Shawn.
-I'm Claire.
We're identical twins.
SHAWN:
What do we have here?
Espresso martini
with Grey Goose.
-Thank you so much.
-BARTENDER: Pleasure.
SHAWN: We always want
to be competitive
to help the other one
get better.
For all we know,
this competition
between us maybe makes us
the unstoppable force
of Project Runway.
There you are.
-Hey! Someone else!
-Ladies.
DEYONTÉ:
It's just such
an emotional roller coaster
right now.
My wife is getting ready
to deliver our baby,
and I told her,
I was like, "I don't know if,
you know, with the baby
coming..." She was like,
"You've got to do it,
for me and the baby."
-DEYONTÉ: Hey!
-Hi!
Welcome to the party!
This is... You're twins!
No, we're triplets.
[laughs]
-The name's Shawn.
-And Claire.
We tell people, Shawn shaved...
-BOTH: Claire hair.
-Love it.
Yeah, where you from?
Uh, I'm from Puerto Rico.
MARGARITA:
My aesthetic is very much
like my personality.
It's fun, it's bright.
You will never see some bland,
dull [bleep]
come out of this designer.
It's the Puerto Rican in me,
okay?
-Ah. -SHAWN: Hey!
-CLAIRE: Who do we have here?
-Hey. -Samantha.
-I'm Shawn.
You guys look a lot alike.
KENTARO:
I got into fashion because
I kind of liked it.
-[laughter] -Okay.
-MARGARITA: I love it.
SHAWN:
Oh! Hey!
AMY:
I'm a fashion design professor
for Otis College
of Art and Design
in Los Angeles.
My trunk is packed full
of wisdom,
so I don't think
that this is gonna be that hard.
[indistinct chatter]
CLAIRE:
Oh, my... you look great!
BATANI: Trends, they come
and go. I just feel like
I have a style
that will last forever.
-So is that...
-This is, like, insane.
I know,
this is kind of surreal, right?
-Kenya.
-Kenya? -Kenya.
-Lovely to meet you, I'm Shawn.
-Shawn?
-You have beautiful
purple lipstick. -I know.
CLAIRE:
What is your design aesthetic?
Uh, free.
More like androgynous
and playing with, like,
-masculinity and femininity.
-Uh-huh.
DEYONTÉ:
Oh, holla!
-SHAWN: Hello!
-How are you?
-Hey there, what's your name?
-Brandon.
-Brandon? -What kind of stuff
do you design?
It's been, like,
all, uh, menswear, actually.
All menswear! Very good.
-Hi!
-What's your name?
-I'm ChaCha.
-ChaCha! -ChaCha.
My name is Vincent,
and everybody calls me ChaCha.
I'm trying to tell people
that you can be fun,
flirty and wacky,
but you still can fit
in the fashion world.
-Oh, my God, what is happening?
-[murmuring]
[laughter]
[horn honking]
DEYONTÉ:
That is dope.
[laughter, chattering]
MARGARITA:
Oh, [bleep],
it's real life! It's happening.
♪ ♪
-[cheers and applause]
-Hi, guys!
Hi, everybody!
BRANDON:
Heidi walks out
and she's, you know,
looking gorgeous as ever.
Her smile kind of
lights up the room.
Greetings, designers!
Welcome to season 16
of Project Runway!
[cheers]
AYANA: I really cannot believe
that I'm here, it's...
it's insane.
Designers, congratulations
for making it here.
We know it's been a daunting
process for all of you.
-OTHERS: Yes. -TIM:
And I'm glad you took advantage
of the Grey Goose espresso
martini c*ck
we provided for you,
because you're going to need
the extra boost of caffeine.
Oh, my gosh.
-And you want to know why?
-Why?
Your first challenge begins now.
-[screams]
-Whoo!
HEIDI:
That's right.
It begins right now.
-Oh, my gosh.
-Oh.
You will be creating
a red carpet look
that showcases who you are
-as a designer.
-Wow. -Yes.
DEYONTÉ: I'm excited.
I'm a red carpet designer,
so to get that
as the first challenge,
I just feel like I got
to blow this out of the box.
HEIDI:
Designers, you should always be
expecting the unexpected
here on Project Runway.
-I'll say.
-So let's start...
with the first surprise.
-Oh, my God.
-[murmuring]
Ladies, come on out!
[chuckling]
♪ ♪
[cheers and applause]
MARGARITA: Model one comes out,
typical skinny, tall girl,
and then model three comes out
with real curves, real body.
-Yeah!
-[cheers and applause]
SENTELL:
Plus-size, medium-size,
skinny, I'm already
freaking out.
But I love it,
because it really challenges us.
This season, you will be working
with models of all sizes.
These stunning women range
in size from two to 22.
[cheers and applause]
HEIDI: I have to tell you,
I'm very, very excited
about this because
the truth of fashion is
that one size does not fit all.
SAMANTHA:
I am in my wheelhouse.
I can design for so many sizes.
HEIDI: Your models have been
randomly assigned.
TIM:
With every challenge,
you will be assigned
a new model.
[chuckling]
Yay! Oh, my God!
I'm so excited!
TIM: All right, designers,
you will have five minutes
to measure your models,
and then you're going to have
Then we're going shopping
at Mood
-with a budget of $300.
-[whistles]
-Okay.
-And, listen up, everyone,
you have one day
for this challenge.
-Okay.
-TIM: All right?
-[laughs]
-SHAWN: I mean, 300 bucks,
-that's... eh, that's nothing
to scoff at, for sure. -No.
But one day, yes!
Designers, I see you back
on the runway,
and, models, I cannot wait
to see you strut your stuff.
-ALL: Yeah.
-Good luck!
BOTH:
Mwah!
HEIDI:
Bye, everybody!
-Bye.
-Bye, Heidi!
-[applause]
-All right.
Measure away.
♪ ♪
Teeny, tiny wrist.
[chuckles]
Seeing this kind of selection
of people is so cool.
And then let me have you just go
like this to the side for me.
Yeah. Just want to make sure
I had your waist.
-AARON: Gonna need a 28.
-DEYONTÉ: 31.
-BRANDON: 44 and a half.
-MARGARITA: We are done, girl.
TIM: Designers, say good-bye
to your models for the moment.
They'll be back later today
-for a fitting.
-Thank you! I'm so excited.
All right, designers,
your 30 minutes of sketching
begins right now.
You can sketch your design ideas
with the new FriXion Erasable
Pens by Pilot.
They allow you to sketch,
erase, and sketch again.
-Go at it.
-I need this for my nerves.
AYANA:
So, my outfit's gonna be
really, really nicely fitted,
more of a sheath style.
I am Muslim and I do cover.
I definitely want to represent
and show that
you can still have
the modest aspect of things
but still be current
and trendy and fashion-forward.
♪ ♪
The vibe in this room
is intense.
I'm definitely
o-out of my element
being in the room with all
these womenswear designers.
It's kind of, you know,
got me questioning
did I do the right thing?
Am I in the right place
being here?
You know, should I leave,
should I stay?
All right, designers,
time is up.
-And we are off to Mood,
all right? -[whoop] -Yay!
BRANDON: It's really, you know,
a trying time.
TIM:
Off we go.
HEIDI:
Coming up on Project Runway...
-[laughs]
-Love it.
-Aah!
-It is badass.
DEYONTÉ:
Watch out, the pressure is on.
-I'm now crazy about it.
-Wonderful.
[groans]
Job well done.
Expecting a lot from you.
-A bit of a cop-out.
-For sure.
TIM:
All right, everyone.
-You ready?
-Yes. -Yay.
AARON:
So, our first challenge is
the red carpet challenge.
-Off they go.
-Yes, gowns. Love it.
I'm gonna create a jumpsuit.
Kind of a textured sweater.
A red overcoat.
[shouting]
CHACHA:
Everybody's running.
I-I don't know why I'm running.
Please, baby Jesus. Oh, yes.
The decision's made.
Okay, so, this is
what it's gonna be.
This is the one.
Done!
Let's do six yards.
I see Deyonté with this print,
and it's huge and it could be
a real nightmare.
-Thank you, thank you.
-KUDZANAI: Awesome sauce.
Threads, we got snaps.
-CASHIER: 98 cents to spare.
-[laughs]
-You haven't seen the workroom.
-No, we have not. -No. -No.
So, let's get acquainted
with it. It's your new home.
Thank you, Mood!
♪ Dun, dun, dun. ♪
-[laughter]
-Yes! -Yes!
-[indistinct chatter]
-Yay!
-Yeah. Real, girl.
-Here we go!
[whistles]
SAMANTHA:
I'm so excited.
-DEYONTÉ: Make it work.
-Oh, look at that.
BRANDON:
Working with plus-size,
curvy models
really got me shook.
But my girlfriend, my mom,
my dad, they're all on my side.
And so I just get back out there
and get to work.
DEYONTÉ: It's about to get hot
in this kitchen.
[designers greet Tim]
Well, welcome to your workroom!
[cheering]
The JCPenney accessory wall
is your resource for styling
your looks for the runway.
-All right. -And next door
is the Brother sewing
and embroidery studio.
-Yeah.
-Very good.
Now, as you know,
this is a one-day challenge,
and today that means you have
until 10:30 tonight. All right?
All right, everyone,
I will be back to see you later.
-I know you will work hard.
-[designers say good-bye]
DEYONTÉ:
Watch out, the pressure is on.
Needed a little sparkle.
No, no, no, no.
SENTELL:
I love menswear because
I-I like to design
what I like to wear.
AARON:
Oh, my God, it's a battle
-of the menswear designers.
-[laughter]
SAMANTHA: I want her to have
a little bit of cleavage
but have it be, like,
business cleavage.
-Business cleavage?
-Business cleavage.
-Are you still cutting, Ayana?
-Yeah, I have to cut sleeves.
CHACHA: I feel like I'm having
a hard time
with just patterning,
sewing, or make things fit.
Wait, that sounds like the whole
meaning of the competition.
ChaCha, what you making?
A short dress and, uh, sleeves.
My form is also too fat.
Like, so fat, and...
-[laughter]
-So it's different.
Well, we have to use
another word than "fat."
-KENYA: Family size.
-Family size?
AYANA: I don't have any personal
feelings towards the wording,
as long as a plus-size model
is not seen
as a problem-size model.
-ALL: Hi, Tim!
-TIM: Hi.
Kenya. I can't wait
to talk about your design,
but first I want to hear
a little bit about
your background.
Well, I'm just a little, short,
bald-headed girl from Atlanta.
I saw you at Mood
with this ice cream color.
Yes, I like ice cream.
Immediately, when you guys said
"red carpet,"
I'm like, okay, my girl's
going to the Oscars.
-Okay.
-So I wanted to give her
strapless,
some exaggerated pockets.
TIM: Your lines are
beautifully clean.
-It has dramatic impact without
becoming silly. -Okay. Mm-hmm.
-It's very alluring.
-I could have fainted!
-Thank you, Tim.
-I can't wait to see this.
Tim likes what
I'm doing right now.
Amy, tell me about you.
I am a professor
of fashion design
at Otis College
of Art and Design.
Oh, how wonderful.
I love Otis.
-Do you? Oh, good.
-Yes.
Tell me about
what you're designing.
The skirt is actually a wrap,
and a cigarette pant underneath.
-I'm excited about this.
-Thank you.
So, Aaron, tell me about you.
Since I have a menswear
background,
I kind of had this idea
of, like, what a tuxedo means.
So the pant is actually
gonna be a top,
and then the bottom
is gonna be a shirt.
I was very concerned about this
when I walked over.
I became a little more concerned
when you started to explain it.
And I'm now crazy about it.
That's, like, really amazing
coming from you.
So, I'm doing
a really wide palazzo pant
out of this silk jersey,
and a kind of detachable cape.
I also have these brights,
'cause I don't want it
just to be all red.
I kinda want to add
a little Margarita.
[laughs]
-Hi, Tim.
-Hi.
So, ChaCha, tell me
about your own aesthetic.
I like cute stuff.
Probably Ariana Grande
or Miley Cyrus will wear.
-Okay.
-So I found this fabric,
and I love it, 'cause it's,
like, sparkly.
Do you think I should
put this, like, over here?
I try my best to explain
my look to Tim,
but Tim just like this.
I don't know what to do.
[groans]
HEIDI:
Coming up on Project Runway...
If you want a sense
of tackiness, you've got it.
-Indeed.
-"Indeed."
-It just seems so basic.
-Exactly.
This doesn't look
"red carpet" to me.
-I think you're gonna
m*rder this. -Aah...
Do you think I should put this,
like, over here?
I think you should do
whatever the design voice in you
tells you to do.
You either commit to it
or you don't.
You have some decisions to make.
-All right.
-Thank you, Tim.
Thank you.
I want to hear all about
your design, of course,
-but I also want to hear
about your background. -Sure.
So the way that we operate
is that Shawn,
her style, it's more edgy,
more cu... cutting-edge.
Mine, more feminine.
So you're not aesthetic twins.
No.
Shawn and Claire get into
this enunciation thing,
where they are quite pleased
with what is going on.
I'm pleased at where
I'm at thus far.
And they are quite happy
to be showing you
how their process is.
I do more of the
conceptualizing.
So for me to be here,
to take it from beginning to end
is daunting.
I think there's something
familial happening.
Indeed. Indeed.
"Indeed. Indeed."
I would never have
been able to predict this.
-Indeed.
-"Indeed."
-[gasps] -What I did was, like,
almost like a reflecting thing,
so it'll be one pocket
on this side
and the following pocket
on the other side.
Conceptually, I'm crazy about
-what you're doing.
-Thank you.
I like a sort of sense
of tackiness.
-If you want a sense
of tackiness, -Yeah.
-you've got it.
-Yeah.
So I feel like, when people
hear the word "modest,"
they think that it's
gonna be boring or dated
-or look, you know, very old.
-And they're completely wrong.
What I-- I need to make
this neckline lower
and then have some of these
appliqués come around.
And then add these elements
to give it some pop.
I feel as though most
of your ambitions
-are in the embellishments.
-Mm-hmm.
I just don't want
the embellishments
to be stripped away
in people's heads,
-and have them ask,
well, what's left? -Hmm.
So, my model was tall, curvy,
and I picture her going
to, like, Cannes,
somewhere kind of resorty.
It's very figure-flattering.
So I've just kind of been
playing with it.
It's supposed to be one piece,
but I draped this first,
and I'm liking the way
the flower
kind of falls
all the way down.
-You draped-draped it
on the bias? -Yes.
-I'm just really ready to fit
it on her so I can see -Yeah.
what other details and changes
I want to make with it.
-I'm gonna be honest with you.
-Okay.
I have a serious problem
with large-scale prints.
Except in this case.
Yes.
[laughs]
Yes, yes, yes, yes, yes!
My style
is kind of more minimal,
but I-I do like luxury finishes,
so I'm trying to make it
look super lux.
Hopefully it feels
kind of modern.
It just seems so basic.
Okay.
Your execution has to be
-absolutely impeccable.
-Okay.
MARGARITA: This guy does
menswear, he's doing women's.
Like, this doesn't look
red carpet to me.
TIM:
Brandon, carry on.
There's a lot riding on this.
BRANDON:
I'm out of my element.
It's got me questioning myself
and my abilities.
I'm just worried about how
I'm even gonna get this done.
TIM:
All right, designers.
Momentarily, your models
will be coming in.
You will have
until 10:30 tonight.
Tomorrow morning, you will have
about two hours in the workroom.
I hate to leave you, but I will
see you in the morning.
-All right.
-Thank you so much, Tim! -Okay?
-Good night, I'll see you later.
-Thank you.
Bye-bye.
♪ ♪
He didn't really say anything.
Tim's advice is blurry.
He didn't really give me
any feedback for it.
[whispers]:
What should I do?
Aah...
Hey, what's up?
AYANA:
Hey!
How are you feeling?
Um, overwhelmed, I'll tell you.
-There we go.
-All right, cool.
KENYA:
Yeah, I like this fit.
It's gonna look nice once
I take it all in like this.
JANINE:
I love Kenya's vibe.
She has that feeling of making
you feel very comfortable.
I think you're gonna
m*rder this.
Oh, yes.
SAMANTHA:
That's cute.
I like it.
[gasps]
You look so cute.
-My dress looks so good on
Yordonos. -Oh, that's awesome.
It's so different
than putting it on a mannequin.
Walk, baby, walk.
I have to make sure that this
is gonna, like, hit your bust
in the right place.
SAMANTHA:
Yeah, I like that. It's cute.
KATIE:
My dress has, like,
a vintage feel,
but it could be
a little matronly.
I don't want to look old,
covered-up and like I'm a mom.
SAMANTHA:
Let's do it.
Hold this right here
for me, please.
AMY: Oh, that fits you
perfectly, oh, my God.
Ugh, I knew it.
AYANA: You don't want the neck
to be super high.
You are doing a great thing
for the curves, I love it.
JAZZMINE:
When I first met Batani, I saw
-that she was excited that I was
her model. -Feels really good.
That's good to have
in the plus-size community,
somebody that's excited
to make us look good.
LIRIS: I'm a little worried
about the top.
If he does not get the top
right, he may be in trouble.
Is the crop top gonna be fitted?
BRANDON: No, I think
I'm gonna keep it loose.
I want something
that accentuates my body.
-'Cause it shows off
what I have. -BRANDON: Mm-hmm.
-Do you mind
if I just kind of... -Nope.
I'm obsessed with the look,
let me tell you right now.
I want to go to sleep
in that look.
I want to wake up in that look.
Everything about that look
is perfect for me.
SHAWN:
Oh, yeah. I like that much more.
Yay.
DEYONTÉ:
Smoking.
I love this color;
this is my color.
I think Deyonté took that
into consideration,
just, the color scheme
on my skin complexion.
DEYONTÉ: I told them you were
going to Cannes Film Festival.
I can't say I have ever seen a
woman in Cannes wear that thing.
Bye, see you tomorrow.
LENA:
Bye! I wish you luck.
-We're gonna rock it tomorrow.
-Yes.
KENYA: Oh, my God. I cannot
believe my zipper is lopsided.
Like, I have to take
this whole thing out.
DEYONTÉ:
You got it, you got it.
[exhales]
SAMANTHA: You sound like
a damsel in distress.
Just so nerve-racking,
not being finished
when I want to be finished.
KUDZANAI: Just got to keep
working under this pressure.
♪ ♪
All right, guys, it's time to go
check in to our hotel.
-We'll be back tomorrow.
-[groaning] -Okay.
Adios.
♪ ♪
Ooh!
Oh, wow.
Amazing.
Can you guys believe that you're
in the room with the winner?
-Hey.
-[laughs]
-Final four, guys.
-Oh-- final four?
[laughter]
DEYONTÉ:
Oh, man, today was long.
Who told me this
was gonna be this hard?
CHACHA:
Can we watch TV?
DEYONTÉ:
Go to bed.
HEIDI:
Coming up on Project Runway...
TIM: We're going down
to the runway!
-[whooping]
-Our first show!
MARGARITA:
I cannot stop sweating.
I don't want to be that girl
that goes home on the first day.
♪ ♪
Morning!
Morning, Amy.
AMY:
Good morning, ChaCha.
Work hard, play hard.
Today, I'm going with my gut,
so I'm adding as many
pink ruffles as I can
-to ChaCha it up.
-[bell chimes]
MARGARITA: I'm legit so nervous
that I cannot stop sweating.
I don't want to be that girl
that goes home on the first day.
-Hi, Tim.
-Hi, Tim.
-Good morning, designers.
-Hey, Tim. -Morning.
TIM: I am sending your models
in momentarily.
-Okay.
-You will have two hours
to send them
to the Avon Beauty Lab
-and to our hair studio,
all right? -All right. -Okay.
TIM:
Use the JCPenney accessory wall
very thoughtfully.
Are we gonna have
a fabulous show?
ALL:
Yes!
I'm sending in your models.
ALL:
Thank you, Tim!
-Hi! -Hi, ladies.
-Hey, guys.
CHACHA:
How are you, princess?
-You feel good?
-JANINE: Yeah.
KENYA: I have a lot of fabric
that I need to hem.
I'm hoping that I can get done
in time,
but I don't know.
I'm in love with it, oh, my God.
CHACHA:
Aw, so beautiful.
There you go,
like, work that side.
CLAIRE:
That's it.
-That looks great.
-SHAWN: Yeah.
♪ ♪
-Nice to meet you. This is
Samantha. -Hi, how are you?
So Samantha's gonna be rocking
a red ensemble
with these accents here.
HECTOR: Just a little touch
of the fuchsia.
-MARGARITA: Love it. Thank you!
-Perfect.
-Hello! -Hey! What I want to do
is highlight the eyes.
HECTOR: So what I can do
is do this first.
And, after that,
go in with the eyeliner,
-blend it together.
-MICHAEL: I love that, yeah.
DEYONTÉ:
Yes, baby. Yes.
DEYONTÉ: I'm so happy it came
together the way it did.
I feel like I am a contender.
KENYA: ChaCha's look
has a lot going on.
It looks like she could
be the host
of the circus under the stars.
Nice.
LIRIS: Last night,
I was really concerned
about the top that Brandon
was making me.
But he pulled it together.
♪ ♪
Designers and models,
we're going down to the runway!
-[whooping]
-Our first show!
I'm ready.
I can't get any more ready.
TIM:
Off we go.
Oh, I like the camo.
[squealing]
-Whoo!
-Hello.
[all greeting]
Welcome to the runway.
DESIGNERS:
Thank you.
There are so many of you here.
I see everyone is still smiling.
As you know, in fashion,
one day you're in,
and the next day you're out.
This season on Project Runway,
you will be working with
models of all sizes.
Because one size
does not fit all.
For this challenge,
we asked you to create
a red carpet look showcasing
your point of view
as a designer.
Now for the big prize.
The winner of Project Runway
will receive the opportunity
to collaborate
with JCPenney
on a limited edition
-capsule collection
-[designers murmuring]
as part of the Project Runway
line sold
at selected JCPenney stores
and online at JCP.com
A selection of Brother products,
including at least
two industrial machines,
with a retail value
-of $40,000.
-[giggling]
Makeup and beauty products
for a year, courtesy of Avon.
-A 2018 Lexus NX.
-[designers whoop]
With advanced innovation and
safety systems coming this fall.
-Holy crap.
-From Pilot,
the official pen
of Project Runway,
a lifetime supply of
FriXion Erasable Pens.
-And an all-expense paid luxury
trip to Japan. -[gasping]
Including a five-star stay
near Japan's fashion center.
$100,000 to launch their line.
-[murmuring] -And the winning
designer and model
will receive a fashion spread
in Marie Claire magazine.
All right, let's say hello
to our judges.
First we have creative director
for Brooks Brothers Women
and fashion designer
-Zac Posen.
-Hi, designers.
-[applause]
-Hi, Zac!
Creative director for
Marie Claire magazine,
Nina Garcia.
Welcome, designers.
-Hi, Nina.
-Hi, Nina.
And actress Olivia Munn.
Starring in the upcoming
Lego Ninjago Movie.
-Welcome.
-DESIGNERS: Hi!
Also, we love
having Tim Gunn here
-for the runway show.
-[kisses]
And as you know,
he is your mentor
and will not be
judging your looks.
That said,
he will have the Tim Gunn save.
-Okay. -We also have
an anonymous runway show,
which means we, the judges,
do not know which designer
created which look.
All right, let's start the show.
♪ ♪
KENYA:
She looks amazing.
The silhouette is beautiful.
The strapless part of the dress
is fitting,
she has her hands in the
pockets that look very lovely
on the dress,
and she is working it.
♪ ♪
KUDZANAI:
I stayed true to myself.
The color is definitely me.
Liz has got the fierce look
on her face.
I'm impressed with myself.
I like it.
♪ ♪
AYANA:
She looks so good.
My fabric is almost sparkling.
It's clean, it's modern,
it's edgy,
but it's still modest,
which is what I design for.
♪ ♪
SHAWN:
I'm in awe.
The movement of
the sleeve and the drape
are in harmony.
This is a winning look for me.
♪ ♪
BATANI: Feeling a little
excited and a little nervous.
This is the first challenge
and the first catwalk.
All these things are running
through my head.
How I should've hand-stitched
the appliqués down more,
so that they could be flat.
I think I should've made
the extensions
a little bit shorter;
they looked like
they were just hanging.
I'm thinking I should've
done something differently.
CLAIRE:
Colleen is rocking
this dress on the catwalk.
She looks absolutely stunning.
You get to see all
the different colors
that I included in it.
The dress is moving so nicely.
It's beautiful.
♪ ♪
BRANDON:
Liris is really strutting it.
She looks confident,
she looks poised.
My heart is beating
out of my chest.
I've never made
women's clothes,
but I just think
it was the right
combination of pieces together.
I'm just so happy with the look
that I put out.
CHACHA:
Oh, my God! She's so cute.
I really love the dress
and I had so much fun with it.
And I see Zac Posen
has a big smile.
I don't know
if it's a good thing
or bad thing, but I just hope
that I could be safe.
AMY: I'm so excited
I can hardly sit still.
I'm absolutely thrilled
with how she is able to
whip off the jacket
and turn it into a skirt.
It walked a fine line
between classic elegance
and innovation, but I think
I was really successful
with this garment.
SENTELL: Going into this first
runway I'm a little unsure.
I'm watching my model walk
down the runway,
I'm feeling a little better.
It actually comes out
really good.
♪ ♪
KENTARO:
Dress is flowing and beautiful.
It's giving out enough drama
for that red carpet look.
And she looks really beautiful,
so I'm happy.
♪ ♪
DEYONTÉ: She's serving it down
the catwalk.
The fabric is flowing
the way I expected.
The color story is great.
I am so proud of myself.
It's something that I wanted
for so long,
and here it is happening
right in front of me.
It's the best feeling
in the world.
MICHAEL: I have never had a look
walk down a runway,
so having Sanita strut
down the runway and look
really, really cool is the
most exciting thing of the day.
I know I pushed
my design aesthetic
and I incorporated
a lot of glamour,
but I'm wondering
if I pushed it far enough.
♪ ♪
AARON:
I really love my pants.
I think they're really fun and
kind of like a flip-flop on,
like, what a tuxedo would be.
I think it looks really chic.
I like my first look.
♪ ♪
SAMANTHA:
I'm so proud.
She walks with such confidence,
and the dress has
beautiful movement,
the skirt moves like water,
just like I want it to.
Everything is hitting her
amazingly
and she looks like
she loves it.
MARGARITA:
She looks stunning.
Her cape is flying down
the runway,
it looks effortless.
She looks super confident.
I'm so in love
with my first look.
That was a really fun
first runway show.
We have just learned which
designer created which look.
If I call your name,
please step forward.
Batani.
Deyonté.
ChaCha.
Shawn.
Kenya.
Brandon.
Please step forward.
If I have not called your name,
congratulations.
Your scores have qualified you
to move onto the next round.
You can leave the runway.
The six of you had the highest
and the lowest scores.
One of you will be
named the winner,
and one of you
will be out.
The six of you had the highest
and the lowest scores.
One of you will be named
the winner,
and one of you will be out.
All right, let's bring out
your models.
Kenya, I'm gonna start with you.
Please tell us your
point of view as a designer
-and your look for today.
-Well, my point of view
as designer is to make ladies
look like ladies.
I think you were very ambitious
to make a mermaid dress
in one day--
I don't know how you did it.
-Me either.
-Because that is a lot of seams,
-that is a lot of construction.
-Mm-hmm.
-Job well done.
-Thank you.
OLIVIA:
I loved the pockets.
I'm always awkward
on the red carpet.
I never know what to do
with my hands or my face.
But having the pockets
just made it feel
a little bit more youthful
and fresh.
HEIDI:
Good job, Kenya.
-Not a bad start.
-It feels great.
-Shawn.
-I make luxury streetwear.
And Christina here is wearing
this two-piece outfit
that I thought would be
wonderful
for the Billboard Music Awards
or the VMAs.
The top I find quite beautiful.
-Mm-hmm.
-Maybe if there was, like,
a long white skirt
to go with it...
-Okay.
-If that had been long,
we would've had two white
dresses next to each other,
and that would have been
a more interesting dress
and more unexpected.
The shorts are a bit
of a cop-out.
It's like a "C" celebrity that
doesn't have a good stylist.
I see.
-ChaCha.
-Okay, so,
I like, um, fun, flirty,
and cute stuff.
So my girl, she's going
to the VMAs,
and I love sparkle.
Kind of looks like
a scrunchie, I don't know.
There's, like, a lot of things
that I'm channeling,
but they're all not
positive things.
Yeah, I understand this
My Little Pony zone you're in
with the ice cream and the bear
and the colors,
but from a design
point of view,
I don't think there's
much there.
Do you feel comfortable
in that dress?
Uh, yeah.
-Okay.
-Well, yeah, you're in a tent.
-Yeah.
-[laughter]
Deyonté, please tell us
about your look for today.
I envision my girl
at Cannes Film Festival.
I wanted her to be bold
and colorful,
and I feel like
it's a special piece.
The way you've placed
the flower,
I mean, that is beautiful.
-Thank you. -It looks
like you did it with love,
-like you did it with passion.
-I got a Michelle Obama event
-when I saw you in that.
-Yes.
-Expecting a lot from you.
-Thank you.
-Brandon. -Well, I do my best to
let my work speak for myself
because I'm not always
the best at speaking.
I've never done
womenswear, either,
so this is, like, the second
woman's look I've ever done.
I can see with this look
that you know
what's happening right now.
-Mm.
-HEIDI: You know?
This new trend of athleisure
where you see
these athletic stripes
mixed with something
that could be glamorous.
Well done.
-Thank you.
-Batani.
So, my point of view as
a designer is I like to design
for the woman who is bold,
sexy and unique.
At first, it was
a basic silhouette
and I wanted to camouflage
her midsection
to make her feel sexy
and look good.
NINA:
You said it yourself.
This piece of fabric was
a camouflage for her figure.
Instead of camouflaging,
why can't we celebrate
her figure?
As a designer, you can't just
think about the size two.
So, I kind of love this new
runway that we have because
-it has many dimensions,
many proportions. -Mm.
-That's the real world. -Okay,
we've heard what you had to say.
Now we're going
to have a little chat,
and then I'm gonna call you
back onto the runway.
-Thank you.
-Thank you.
-Hi there. Hi.
-Hi, Tim. -Hi, Tim.
-HEIDI: Hello, ladies.
-MONIQUE: Hello.
Shall we start with Monique,
wearing Deyonté?
-It almost looks like he
hand-painted it. -HEIDI: Yeah.
-That's how strategically these
flowers are placed. -HEIDI: Yes.
-It's perfect.
-It's perfect.
HEIDI: It really, like,
cinches in the waist,
-gives you, like, a beautiful
curve. -It's so... a-and this
-whole thing, Heidi.
-HEIDI: Yes.
-Oh, is it a shirt skirt?
-Uh-huh.
-ZAC: It's a top and a skirt.
-How fabulous is that?
-It just lays so effortlessly.
-NINA: Perfectly. -HEIDI: Yeah.
-Well, you look happy.
-I love it.
ZAC: You can tell that he loves
women, and that's really nice.
And Liris is wearing Brandon.
-ZAC: I want to see more.
-HEIDI: Yeah. -NINA: Yeah.
-It's the attitude.
-The attitude.
He gave us something different
for the red carpet,
-and it works.
-NINA: Yes. Absolutely.
And the curve here
of the patterning,
there's subtlety
that's really nice.
He designed for her.
And we have Janine
wearing Kenya.
It's a nice fabric,
but I just think...
But it's too see-through
and it doesn't hold up.
ZAC: Well, she could've
just done a-a lining.
She had intended
to put in a lining.
-It was a matter of time.
-HEIDI: Oh. -ZAC: Yeah.
ZAC: But if somebody
came to my studio
and said I can make something
like that overnight,
they'd be working with the
Oscars with me in a second.
NINA:
Superb.
-I mean, there's boning in it.
-Really?
-ZAC: Yes. -TIM: Yeah.
-It's really beautiful.
TIM: We have Christina
wearing Shawn.
-I like the top part of it.
-ZAC: That's what we said.
-We thought that that had a nice
quality. -Yeah, I agree with you
-completely. -I think, together,
it's a little bit hard,
but that's very beautiful.
TIM:
And we have
Yordonos wearing ChaCha.
ZAC:
Our unicorn, pixie princess.
Yeah, I mean, ChaCha,
I don't know.
He's trying to be ironic
or something?
Yeah, it's like countercultural.
-OLIVIA: That's what it feels
like he's... -I don't...
-I think you're giving him
too much credit. -[laughs]
And we have Jazzmine
wearing Batani.
ZAC: You're just glowing
and bubbly and happy.
-Oh, thank you, thank you.
-Jazzmine.
She said it herself.
The camouflage.
And she's got a great figure.
-TIM: Thank you, judges.
-Bye, girls. -Bye, ladies.
-Bye.
-ZAC: Did awesome.
Really nice to see
all the different body types.
-That's refreshing.
-NINA: Yeah.
All right,
so we've made our decision?
-Yeah. -HEIDI: Let's bring them
back out.
The six of you had the highest
and the lowest scores.
One of you will be named
the winner...
and one of you will be out.
Deyonté, your model looked
effortless and bold
at the same time.
Thank you.
Congratulations, you are
the winner of this challenge.
[chuckles]
-How do you feel?
-It's surreal.
And I got much more to show you
moving forward.
Thank you.
You can leave the runway.
Thank you, judges.
It's like the best feeling
in the world
to win the first challenge.
My wife, we're having a baby,
and I'm here changing our lives.
-[gasps]
-Yo. -What's up?
-I won. [laughs]
-[cheering]
-Good job. -I knew it.
-It's for your baby boy.
[whoops]
It's for my baby boy.
-I needed that. I swear.
-Aw.
Man. Mm-mm-mm.
Kenya, we were very impressed
with what you pulled off today.
-Thank you.
-Brandon, you really embraced
your model's curves,
and we're all looking forward
to seeing more from you.
Thank you.
Shawn.
Your look did not impress us.
That said...
-it's clear that you have
potential. -Thank you.
You're all in.
You can leave the runway.
-Thank you.
-HEIDI: Thank you.
BRANDON:
Thank you, guys.
I have potential!
[designers shouting]
Oh, it's okay.
-She was worried about you.
-SAMANTHA: You're still here.
She was so worried about you.
Batani, ChaCha,
one of you will be out.
ChaCha.
The fabric was beautiful,
but the construction
really was a mess.
Batani.
It concerned us
that you really wanted
to camouflage
your model's curves
rather than embrace them.
Batani...
...you're in.
You can leave the runway.
I'm sorry, ChaCha.
That means you're out.
Thank you
for an amazing experience.
I think I have a lot to learn.
Auf Wiedersehen.
I know it's not easy
being the first one.
-[sighs]
-But thank you for being here.
Thank you guys so much.
-Thank you.
-Thank you.
I appreciate everything.
As the first one to leave,
it's so embarrassing.
[groans]
I feel a little sad
'cause, like, ugh,
I love Heidi so much,
but she don't get me.
-SENTELL: Oh, man.
-[designers groan]
-DEYONTÉ: No, ChaCha. -ChaCha,
there's a girl who loves
what you do as it is already.
You just need to find that girl.
Oh, I thought you were
going to say you.
[laughter]
DEYONTÉ:
He's hilarious!
-Hey, Tim.
-Deyonté.
Wow. But honestly,
it was a sensational show.
-You should each feel proud.
All right? -Yeah. Absolutely.
ChaCha, I need to send you
to the workroom
to clean up your space, okay?
[designers groan, say good-byes]
-Best wishes. Okay?
-Okay.
ChaCha.
-Yes.
-I love you guys.
Bye, everybody. I love you.
[sighs]
Project Runway is actually
like a dream to me.
I just feel really sad
I cannot stay longer.
[groans]
I just regret the ruffles.
HEIDI:
Next time on Project Runway...
SAMANTHA:
It's a giant recycling center.
-Holy [bleep].
-TIM: This is your first
unconventional materials
challenge.
KENYA: I don't work
with anything recycled.
-[groans]
-She seems kind of stressed out.
-You planned beautifully.
-Good.
This is not gonna help you.
This is gonna be a hot mess.
This is what the show is about.
-Utter elegance.
-I'm so impressed.
-♪ Hallelujah. ♪
-[laughs]
You really need to change
your perspective.
-It's like a leprechaun
went Dumpster-diving. -Wow.
HEIDI: Visit MyLifetime.com
to learn more
about the fashion you've seen
on tonight's show.
Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.
Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?
Register or sign in here: ucp.php?mode=register
Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?
Register or sign in here: ucp.php?mode=register
16x02 - One Size Does Not Fit All
Watch/Buy Amazon
Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.
Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.